pub fn generate(rust_dir: &Path, out: &Path) -> Result<()>Expand description
Scan rust_dir (recursively) for #[lingxia::native] / #[native] handlers
and struct definitions, then write a native client to out_path.
If no native handlers are found the output file is removed (clean slate).